idlefw/inc/framework/aicpsexecuteparam.h
branchRCL_3
changeset 15 a0713522ab97
parent 14 15e4dd19031c
child 19 edd621764147
--- a/idlefw/inc/framework/aicpsexecuteparam.h	Wed Mar 31 22:04:35 2010 +0300
+++ b/idlefw/inc/framework/aicpsexecuteparam.h	Wed Apr 14 16:16:44 2010 +0300
@@ -80,13 +80,13 @@
     const TDesC& PluginId() const;
     
     /**
     * Returns the input parameter list for Execute command
     * it will leave the CLiwGenericParamList object in the stack
     * 
     * @since S60 5.2
-    * @return generic parameter list 
+    * @return in param map 
     */    
-    CLiwGenericParamList* InParamListLC();
+    CLiwDefaultMap* InParamMapLC();
    
     /**
     * Adds a actions to the action list
@@ -80,13 +80,13 @@
     
     /**
-    * Returns the input parameter list for Execute command
-    * it will leave the CLiwGenericParamList object in the stack
+    * Returns the input parameter map for Execute command
+    * it will leave the CLiwDefaultMap object in the stack
     * 
     * @since S60 5.2